#
#, fuzzy
msgid ""
msgstr ""
"Project-Id-Version: PACKAGE VERSION\n"
"Report-Msgid-Bugs-To:\n"
"POT-Creation-Date: <%= DateTime.now %>\n"
"PO-Revision-Date: YEAR-MO-DA HO:MI+ZONE\n"
"Last-Translator: FULL NAME <EMAIL@ADDRESS>\n"
"Language-Team: LANGUAGE <LL@li.org>\n"
"MIME-Version: 1.0\n"
"Content-Type: text/plain; charset=UTF-8\n"
"Content-Transfer-Encoding: 8bit\n"
"X-Generator: Translate Toolkit 2.0.0\n"<% if metadata.key?('summary') %>
#. metadata.json
#: .summary
msgid "<%= metadata['summary']%>"
msgstr ""<% end %><% if metadata.key?('description')%>
#. metadata.json
#: .description
msgid "<%= metadata['description']%>"
msgstr ""
<% end %>
